==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/policies_custom_options.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PoliciesCustomOptions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'custom_configuration1_rule': 'str'
    }

    attribute_map = {
        'custom_configuration1_rule': 'custom_configuration1_rule'
    }

    def __init__(self, custom_configuration1_rule=None):
        """PoliciesCustomOptions

        The model defined in huaweicloud sdk

        :param custom_configuration1_rule: 自定义配置规则。
        :type custom_configuration1_rule: str
        """
        
        

        self._custom_configuration1_rule = None
        self.discriminator = None

        if custom_configuration1_rule is not None:
            self.custom_configuration1_rule = custom_configuration1_rule

    @property
    def custom_configuration1_rule(self):
        """Gets the custom_configuration1_rule of this PoliciesCustomOptions.

        自定义配置规则。

        :return: The custom_configuration1_rule of this PoliciesCustomOptions.
        :rtype: str
        """
        return self._custom_configuration1_rule

    @custom_configuration1_rule.setter
    def custom_configuration1_rule(self, custom_configuration1_rule):
        """Sets the custom_configuration1_rule of this PoliciesCustomOptions.

        自定义配置规则。

        :param custom_configuration1_rule: The custom_configuration1_rule of this PoliciesCustomOptions.
        :type custom_configuration1_rule: str
        """
        self._custom_configuration1_rule = custom_configuration1_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoliciesCustomOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/policies_custom_options.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PoliciesCustomOptions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'custom_configuration1_rule': 'str'
    }

    attribute_map = {
        'custom_configuration1_rule': 'custom_configuration1_rule'
    }

    def __init__(self, custom_configuration1_rule=None):
        r"""PoliciesCustomOptions

        The model defined in huaweicloud sdk

        :param custom_configuration1_rule: 自定义配置规则。
        :type custom_configuration1_rule: str
        """
        
        

        self._custom_configuration1_rule = None
        self.discriminator = None

        if custom_configuration1_rule is not None:
            self.custom_configuration1_rule = custom_configuration1_rule

    @property
    def custom_configuration1_rule(self):
        r"""Gets the custom_configuration1_rule of this PoliciesCustomOptions.

        自定义配置规则。

        :return: The custom_configuration1_rule of this PoliciesCustomOptions.
        :rtype: str
        """
        return self._custom_configuration1_rule

    @custom_configuration1_rule.setter
    def custom_configuration1_rule(self, custom_configuration1_rule):
        r"""Sets the custom_configuration1_rule of this PoliciesCustomOptions.

        自定义配置规则。

        :param custom_configuration1_rule: The custom_configuration1_rule of this PoliciesCustomOptions.
        :type custom_configuration1_rule: str
        """
        self._custom_configuration1_rule = custom_configuration1_rule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoliciesCustomOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
